@@ -506,7 +506,7 @@ def _parse_args():
     )
     ca_get_certificate_from_csr_parser.add_argument(
         '--csr-file',
-        help=('A cerftificate signing request (CSR) file to issue a certificate'
+        help=('A certificate signing request (CSR) file to issue a certificate'
               'from.'),
     )
     ca_get_certificate_from_csr_parser.add_argument(
@@ -529,6 +529,59 @@ def _parse_args():
         'list_cas'
     )
 
+    add_creds_to_service_parser = subparsers.add_parser(
+        'add_creds',
+        help=('Add credential ids to a service'),
+    )
+    add_creds_to_service_parser.add_argument(
+        '--cred-ids',
+        type=str,
+        nargs='+',
+        dest='cred_ids',
+        default=[],
+        help=('list of credential ids, separated by whitespace'),
+    )
+    add_creds_to_service_parser.add_argument(
+        '--blind-cred-ids',
+        type=str,
+        nargs='+',
+        dest='blind_cred_ids',
+        default=[],
+        help=('list of credential ids, separated by whitespace'),
+    )
+    add_creds_to_service_parser.add_argument(
+        '--service-id',
+        type=str,
+        dest='service_id',
+    )
+
+    rm_creds_from_service_parser = subparsers.add_parser(
+        'remove_creds',
+        help=('Remove credential ids to a service'),
+    )
+    rm_creds_from_service_parser.add_argument(
+        '--cred-ids',
+        type=str,
+        nargs='+',
+        dest='cred_ids',
+        default=[],
+        help=('list of credential ids, separated by whitespace'),
+    )
+    rm_creds_from_service_parser.add_argument(
+        '--blind-cred-ids',
+        type=int,
+        nargs='+',
+        dest='blind_cred_ids',
+        default=[],
+        help=('list of credential ids, separated by whitespace'),
+    )
+    rm_creds_from_service_parser.add_argument(
+        '--service-id',
+        type=str,
+        dest='service_id',
+        required=True,
+    )
+
     return parser.parse_args()
 
 
@@ -706,6 +759,24 @@ def main():
             ret = client.list_cas()
         except Exception:
             logging.exception('An unexpected general error occurred.')
+    elif args.subcommand == 'add_creds':
+        try:
+            ret = client.add_credentials_to_service(
+                credentials=args.cred_ids,
+                blind_credentials=args.blind_cred_ids,
+                service=args.service_id
+            )
+        except Exception:
+            logging.exception('An unexpected general error occurred.')
+    elif args.subcommand == 'remove_creds':
+        try:
+            ret = client.remove_credentials_from_service(
+                credentials=args.cred_ids,
+                blind_credentials=args.blind_cred_ids,
+                service=args.service_id
+            )
+        except Exception:
+            logging.exception('An unexpected general error occurred.')
 
     print(json.dumps(ret, sort_keys=True, indent=4, separators=(',', ': ')))
     if not ret['result']:
